Class reference
===============

Waiting for https://github.com/sphinx-doc/sphinx/issues/3494 to be resolved...

Session
-------
.. autoclass:: jsonapi_client.session.Session
   :members:

.. automodule:: jsonapi_client.filter
   :members:


Document
--------

.. automodule:: jsonapi_client.document
   :members:

ResourceObject
--------------

.. automodule:: jsonapi_client.resourceobject
   :members:


Relationships
-------------

.. automodule:: jsonapi_client.relationships
   :members:

Other objects
-------------

.. automodule:: jsonapi_client.objects
   :members:

Other
-----

.. automodule:: jsonapi_client.common
   :members:

Exceptions
----------

.. automodule:: jsonapi_client.exceptions
   :members:
